@@ -5,6 +5,7 @@ class PDF::Font::Loader::Dict {
 
     method !base-enc($_, :$dict!) {
         when 'Identity-H'       {'identity-h' }
+        when 'Identity-V'       {'identity-v' }
         when 'WinAnsiEncoding'  { 'win' }
         when 'MacRomanEncoding' { 'mac' }
         default {
@@ -27,7 +28,7 @@ class PDF::Font::Loader::Dict {
     method load-font-opts(FontDict :$dict! is copy, Bool :$embed = True, |c) {
         my %opt;
 
-        %opt<enc> = $_
+        %opt<cmap> = $_
             with $dict<ToUnicode>;
 
         %opt<enc> //= do with $dict<Encoding> {
