@@ -29,30 +29,37 @@ class PDF::Font::Loader::FreeType {
     has uint $.last-char;
     has uint16 @!widths;
     method widths is rw { @!widths }
-    my subset EncodingScheme where 'mac'|'win'|'zapf'|'sym'|'identity'|'identity-h'|PDF::COS::Stream;
+    my subset EncodingScheme where 'mac'|'win'|'zapf'|'sym'|'identity'|'identity-h'|'identity-v'|'std';
     has EncodingScheme $!enc;
     has Bool $.embed = True;
 
     submethod TWEAK(:@differences,
                     :$widths,
-                    :$!enc = self!font-format eq 'Type1' || ! $!embed || $!face.num-glyphs <= 255
+                    PDF::COS::Stream :$cmap,
+                    Str :$!enc = self!font-format eq 'Type1' || ! $!embed || $!face.num-glyphs <= 255
             ?? 'win'
             !! 'identity-h') {
-        die "can't use identity-h encoding with type-1 fonts"
-            if self!font-format eq 'Type1' && $!enc eq 'identity-h';
-        die "can't use identity-h encoding with unembedded fonts"
-            if ! $!embed && $!enc eq 'identity-h';
-        $!encoder = do given $!enc {
-            when PDF::COS::Stream { PDF::Font::Loader::Enc::CMap.new: :cmap($_), :$!face;  }
-            when 'identity'   { PDF::Font::Loader::Enc::Identity.new: :$!face }
-            when 'identity-h' { PDF::Font::Loader::Enc::Identity-H.new: :$!face }
-            default { PDF::Font::Loader::Enc::Type1.new: :$!enc, :$!face; }
+        if $!enc ~~ 'identity'|'identity-h'|'identity-v' {
+            die "can't use $!enc encoding with type-1 fonts"
+                if self!font-format eq 'Type1';
+            die "can't use $!enc encoding with unembedded fonts"
+                unless $!embed;
+        }
+
+        $!encoder = do {
+            when $cmap.defined
+                        { PDF::Font::Loader::Enc::CMap.new: :$cmap, :$!face, :$!enc;  }
+            when $!enc eq 'identity'
+                        { PDF::Font::Loader::Enc::Identity.new: :$!face }
+            when $!enc ~~ 'identity-h'|'identity-v'
+                        { PDF::Font::Loader::Enc::Identity-H.new: :$!face }
+            default     { PDF::Font::Loader::Enc::Type1.new: :$!enc, :$!face; }
         }
 
         $!encoder.differences = @differences
             if @differences;
 
-        @!widths = .list with $widths;
+        @!widths = .map(*.Int) with $widths;
     }
 
     method height($pointsize = 1000, Bool :$from-baseline, Bool :$hanging) {
@@ -183,7 +190,7 @@ class PDF::Font::Loader::FreeType {
         };
     }
 
-    method !unicode-cmap {
+    method !make-unicode-cmap {
         my $CMapName = :name('p6-cmap-' ~ $.font-name);
         my $dict = {
             :Type( :name<CMap> ),
@@ -395,7 +402,7 @@ class PDF::Font::Loader::FreeType {
                     }
                 }
                 $.to-dict<DescendantFonts>[0]<W> = @Widths;
-                $.to-dict<ToUnicode> = self!unicode-cmap;
+                $.to-dict<ToUnicode> = self!make-unicode-cmap;
             }
             default {
                 given $.to-dict {
